@@ -191,6 +191,7 @@ def for_obj_in_selected_objs(context) -> bpy.types.Object:
 
 def for_obj_in_collections(
     collections: List[bpy.types.Collection],
+    filter_mesh: bool = False,
 ) -> bpy.types.Object:
     """Yield objects in list of collection.
 
@@ -199,9 +200,11 @@ def for_obj_in_collections(
     """
     for collection in collections:
         for obj in collection.all_objects:
-            if obj.type == "MESH":
+            if filter_mesh and obj.type == "MESH":
                 # This gives you direct access to data block
                 yield bpy.data.objects[obj.name]
+            else:
+                yield bpy.data.objects[obj.name]
 
 
 def toggle_hidden(
@@ -562,7 +565,7 @@ _SAVED_POSES = {}
 
 def save_pose(
     obj: Union[bpy.types.Object, str],
-    pose_name: str,
+    pose_name: str = None,
 ) -> None:
     """Save a pose (rot and pos) to dict.
 
@@ -572,12 +575,14 @@ def save_pose(
     """
     obj = verify(obj)
     log.info(f"Saving pose {pose_name} based on object {obj.name}")
+    if pose_name is None:
+        pose_name = obj.name
     _SAVED_POSES[pose_name] = obj.matrix_world.copy()
 
 
 def restore_pose(
     obj: Union[bpy.types.Object, str],
-    pose_name: str,
+    pose_name: str = None,
 ) -> None:
     """Restore an object to a position.
 
@@ -587,4 +592,49 @@ def restore_pose(
     """
     obj = verify(obj)
     log.info(f"Restoring pose {pose_name} to object {obj.name}")
+    if pose_name is None:
+        pose_name = obj.name
     obj.matrix_world = _SAVED_POSES[pose_name]
+
+
+def lighting_randomize(
+    energy_jitter: bool = True,
+    jitter: bool = True,
+    energy_range_sun: Tuple[int] = (1, 20),
+    energy_range_point: Tuple[int] = (100, 500),
+) -> None:
+    """Randomizes Lighting.
+    Args:
+        energy_jitter: bool: Whether to jitter the lighting intensity for lights in scene. Defaults to True
+        energy_range_sun: Tuple[int]: Range for intensity for SUN lights in scene.
+        energy_range_point: Tuple[int]: Range for intensity for POINT, SPOT, and AREA lights in scene.
+    """
+    # check if lights are in the scene, if not log error
+    for obj in bpy.context.scene.objects:
+        if obj.type == "LIGHT":
+            continue
+        else:
+            log.debug("add lights to use this function")
+    # Loop through objects in scene and randomly toggle them on and off in the render,
+    # these will still be visible in preview scene
+    for obj in bpy.data.lights:
+        if obj.type == "POINT" or obj.type == "SPOT" or obj.type == "AREA":
+            bpy.data.objects[obj.name].hide_render = bool(random.randint(0, 1))
+            if energy_jitter:
+                bpy.data.objects[obj.name].data.energy = random.randint(
+                    *energy_range_point)
+        if obj.type == "SUN":
+            bpy.data.objects[obj.name].hide_render = bool(random.randint(0, 1))
+            if energy_jitter:
+                bpy.data.objects[obj.name].data.energy = random.randint(
+                    *energy_range_sun)
+            # bpy.data.scenes["Scene"].world.use_nodes = True
+        if jitter:
+            zpy.objects.jitter(
+                obj.name,
+                translate_range=(
+                    (-2, 2),
+                    (-2, -2),
+                    (1, 5),
+                ),
+            )
