@@ -2,9 +2,7 @@
     Segment panel and functions.
 """
 import importlib
-import json
 import logging
-import random
 from typing import Tuple
 
 import bpy
@@ -19,16 +17,13 @@ if "bpy" in locals():
 
 
 def registerObjectProperties():
-    """ Properties applied to object."""
-    bpy.types.Object.seg = bpy.props.PointerProperty(
-        type=SegmentableProperties)
+    """Properties applied to object."""
+    bpy.types.Object.seg = bpy.props.PointerProperty(type=SegmentableProperties)
 
 
 def registerSceneProperties():
-    """ Properties applied to scenes."""
-    bpy.types.Scene.categories = bpy.props.CollectionProperty(
-        type=CategoryProperties
-    )
+    """Properties applied to scenes."""
+    bpy.types.Scene.categories = bpy.props.CollectionProperty(type=CategoryProperties)
     bpy.types.Scene.categories_enum = bpy.props.EnumProperty(
         name="Category",
         description="Category for this object.",
@@ -39,34 +34,37 @@ def registerSceneProperties():
 
 
 class CategoryProperties(bpy.types.PropertyGroup):
-    """ Segmentation category is a property of one or many objects. """
+    """Segmentation category is a property of one or many objects."""
+
     name: bpy.props.StringProperty(
         name="Category Name",
         description="String name of the category.",
     )
     color: bpy.props.FloatVectorProperty(
         name="Category Color",
-        subtype='COLOR',
+        subtype="COLOR",
         description="Category color for segmentation.",
     )
 
 
 def _category_items(self, context):
-    """ Get current categories. """
+    """Get current categories."""
     _categories_enum = []
     for i, (name, category) in enumerate(bpy.context.scene.categories.items()):
         # Add category to ENUM tuple
-        _categories_enum.append((
-            # First item is used for Python access.
-            str(i),
-            name,
-            zpy.color.frgb_to_hex(category.color),
-        ))
+        _categories_enum.append(
+            (
+                # First item is used for Python access.
+                str(i),
+                name,
+                zpy.color.frgb_to_hex(category.color),
+            )
+        )
     return _categories_enum
 
 
 def _category_update(self, context):
-    """ Update the category. """
+    """Update the category."""
     if context.selected_objects:
         # Use the value of the category enum dropdown
         category = context.scene.categories[int(context.scene.categories_enum)]
@@ -83,161 +81,159 @@ class SegmentableProperties(bpy.types.PropertyGroup):
     category_name: bpy.props.StringProperty(
         name="Category Name",
         description="String name of the category.",
-        default='',
+        default="",
     )
     category_color: bpy.props.FloatVectorProperty(
         name="Category Color",
-        subtype='COLOR',
+        subtype="COLOR",
         description="Category color for segmentation.",
     )
     instance_name: bpy.props.StringProperty(
         name="Instance Name",
         description="String name of the instance.",
-        default='',
+        default="",
     )
     instance_color: bpy.props.FloatVectorProperty(
         name="Instance Color",
-        subtype='COLOR',
+        subtype="COLOR",
         description="Instance color for segmentation.",
     )
 
 
 class SegmentInstanceMany(Operator):
-    """ Segment the selected objects/parts.
+    """Segment the selected objects/parts.
 
     Each object will be segmented as a unique object.
 
     """
+
     bl_idname = "object.zpy_segment_instance_many"
     bl_label = "Segment Instance (Many)"
-    bl_options = {'REGISTER', 'UNDO'}
+    bl_options = {"REGISTER", "UNDO"}
 
     @classmethod
     def poll(cls, context):
         return len(context.selected_objects) > 0
 
     def execute(self, context):
-        context.space_data.shading.color_type = 'OBJECT'
+        context.space_data.shading.color_type = "OBJECT"
         for obj in zpy.objects.for_obj_in_selected_objs(context):
             zpy.objects.segment(obj=obj, name=obj.name)
-        return {'FINISHED'}
+        return {"FINISHED"}
 
 
 class SegmentInstanceSingle(Operator):
-    """ Segment the selected objects/parts.
+    """Segment the selected objects/parts.
 
     All objects will be segmented as a single instance.
 
     """
+
     bl_idname = "object.zpy_segment_instance_single"
     bl_label = "Segment Instance (Single)"
-    bl_options = {'REGISTER', 'UNDO'}
+    bl_options = {"REGISTER", "UNDO"}
 
     @classmethod
     def poll(cls, context):
         return len(context.selected_objects) > 0
 
     def execute(self, context):
-        context.space_data.shading.color_type = 'OBJECT'
+        context.space_data.shading.color_type = "OBJECT"
         # Pick a random color and instance name
         _name = context.selected_objects[0].name
-        _color = zpy.color.random_color(output_style='frgb')
+        _color = zpy.color.random_color(output_style="frgb")
         for obj in zpy.objects.for_obj_in_selected_objs(context):
             zpy.objects.segment(obj=obj, name=_name, color=_color)
-        return {'FINISHED'}
+        return {"FINISHED"}
 
 
 class VisualizeInstance(Operator):
-    """ Visualize the instance colors on objects in scene. """
+    """Visualize the instance colors on objects in scene."""
+
     bl_idname = "object.zpy_visualize_instance"
     bl_label = "Visualize Instances"
-    bl_options = {'REGISTER', 'UNDO'}
+    bl_options = {"REGISTER", "UNDO"}
 
     def execute(self, context):
-        context.space_data.shading.color_type = 'OBJECT'
+        context.space_data.shading.color_type = "OBJECT"
         # Loop through all objects in the scene
         for obj in context.scene.objects:
-            if not obj.type == 'MESH':
+            if not obj.type == "MESH":
                 continue
             context.view_layer.objects.active = obj
             if obj.seg.instance_color is not None:
-                obj.color = zpy.color.frgb_to_frgba(
-                    obj.seg.instance_color)
+                obj.color = zpy.color.frgb_to_frgba(obj.seg.instance_color)
             else:
-                obj.color = zpy.color.default_color(output_style='frgba')
-        return {'FINISHED'}
+                obj.color = zpy.color.default_color(output_style="frgba")
+        return {"FINISHED"}
 
 
 class VisualizeCategory(Operator):
-    """ Visualize the category colors on objects in scene. """
+    """Visualize the category colors on objects in scene."""
+
     bl_idname = "object.zpy_visualize_category"
     bl_label = "Visualize Categories"
-    bl_options = {'REGISTER', 'UNDO'}
+    bl_options = {"REGISTER", "UNDO"}
 
     def execute(self, context):
-        context.space_data.shading.color_type = 'OBJECT'
+        context.space_data.shading.color_type = "OBJECT"
         # Loop through all objects in the scene
         for obj in context.scene.objects:
-            if not obj.type == 'MESH':
+            if not obj.type == "MESH":
                 continue
             context.view_layer.objects.active = obj
             if obj.seg.category_color is not None:
-                obj.color = zpy.color.frgb_to_frgba(
-                    obj.seg.category_color)
+                obj.color = zpy.color.frgb_to_frgba(obj.seg.category_color)
             else:
                 obj.color = zpy.color.default_color()
-        return {'FINISHED'}
+        return {"FINISHED"}
 
 
 class ResetSegData(Operator):
-    """ Reset the segmentation data on the selected objects/parts. """
+    """Reset the segmentation data on the selected objects/parts."""
+
     bl_idname = "object.zpy_reset_seg_data"
     bl_label = "Reset Segmentation Data"
-    bl_options = {'REGISTER', 'UNDO'}
+    bl_options = {"REGISTER", "UNDO"}
 
     @classmethod
     def poll(cls, context):
         return len(context.selected_objects) > 0
 
     def execute(self, context):
-        context.space_data.shading.color_type = 'OBJECT'
+        context.space_data.shading.color_type = "OBJECT"
         for obj in context.selected_objects:
             # Only meshes or empty objects TODO: Why the empty objects
-            if not (obj.type == 'MESH' or obj.type == 'EMPTY'):
+            if not (obj.type == "MESH" or obj.type == "EMPTY"):
                 continue
-            obj.seg.instance_name = ''
-            obj.seg.instance_color = zpy.color.default_color(
-                output_style='frgb')
-            obj.seg.category_name = 'default'
-            obj.seg.category_color = zpy.color.default_color(
-                output_style='frgb')
-            obj.color = zpy.color.default_color(output_style='frgba')
-        return {'FINISHED'}
+            obj.seg.instance_name = ""
+            obj.seg.instance_color = zpy.color.default_color(output_style="frgb")
+            obj.seg.category_name = "default"
+            obj.seg.category_color = zpy.color.default_color(output_style="frgb")
+            obj.color = zpy.color.default_color(output_style="frgba")
+        return {"FINISHED"}
 
 
 def _reset_categories(context):
-    """ Reset the scene categories. """
+    """Reset the scene categories."""
     # Clean out the scene-level category dict
     for _ in range(len(context.scene.categories)):
         context.scene.categories.remove(0)
     # Reset all categories
     for obj in zpy.objects.for_obj_in_selected_objs(context):
-        obj.seg.category_name = 'default'
-        obj.seg.category_color = zpy.color.default_color(
-            output_style='frgb')
-        obj.color = zpy.color.default_color(output_style='frgba')
+        obj.seg.category_name = "default"
+        obj.seg.category_color = zpy.color.default_color(output_style="frgb")
+        obj.color = zpy.color.default_color(output_style="frgba")
 
 
-def _add_category(context,
-                  name: str = None,
-                  color: Tuple[float] = None) -> None:
-    """ Add category to enum category property. """
+def _add_category(context, name: str = None, color: Tuple[float] = None) -> None:
+    """Add category to enum category property."""
     if name in context.scene.categories.keys():
-        log.warning(f'Skipping duplicate category {name}.')
+        log.warning(f"Skipping duplicate category {name}.")
         return
     if color is None:
-        color = zpy.color.random_color(output_style='frgb')
-        log.info(f'Choosing random color for category {name}: {color}')
+        color = zpy.color.random_color(output_style="frgb")
+        log.info(f"Choosing random color for category {name}: {color}")
     # Add category to categories dict
     new_category = context.scene.categories.add()
     new_category.name = name
@@ -245,7 +241,8 @@ def _add_category(context,
 
 
 class CategoriesFromText(Operator):
-    """ Populate categories from text block. """
+    """Populate categories from text block."""
+
     bl_idname = "object.zpy_categories_from_text"
     bl_label = "Categories from Text"
 
@@ -261,12 +258,13 @@ class CategoriesFromText(Operator):
             txt.new("categories")
             category_text = txt["categories"]
 
-        assert category_text is not None, \
-            f'Category text block must exist for segmentation.'
+        assert (
+            category_text is not None
+        ), "Category text block must exist for segmentation."
 
         # Activate the categories text block in the text editor
         for area in context.screen.areas:
-            if area.type == 'TEXT_EDITOR':
+            if area.type == "TEXT_EDITOR":
                 space = area.spaces.active
                 space.text = category_text
 
@@ -274,41 +272,41 @@ class CategoriesFromText(Operator):
 
         for line in category_text.lines:
             _add_category(context, name=line.body)
-        return {'FINISHED'}
+        return {"FINISHED"}
 
 
 class CategoriesFromZUMOJSON(Operator, ImportHelper):
-    """ Populate categories from Zumo JSON. """
+    """Populate categories from Zumo JSON."""
+
     bl_idname = "object.zpy_categories_from_zumo"
     bl_description = "Categories from Zumo JSON"
     bl_label = "Import"
 
-    filter_glob: bpy.props.StringProperty(
-        default='*.json', options={'HIDDEN'})
+    filter_glob: bpy.props.StringProperty(default="*.json", options={"HIDDEN"})
 
     def execute(self, context):
         zumo_json = zpy.files.read_json(self.filepath)
-        categories = zumo_json.get('categories', None)
-        assert categories is not None, \
-            f'ZUMO JSON does not have categories.'
+        categories = zumo_json.get("categories", None)
+        assert categories is not None, "ZUMO JSON does not have categories."
         _reset_categories(context)
         for category in categories.values():
             _add_category(
                 context,
-                name=category.get('name', None),
-                color=category.get('color', None),
+                name=category.get("name", None),
+                color=category.get("color", None),
             )
-        return {'FINISHED'}
+        return {"FINISHED"}
 
 
 class SCENE_PT_SegmentPanel(bpy.types.Panel):
-    """ UI for the addon that is visible in Blender. """
-    bl_idname="SCENE_PT_SegmentPanel"
+    """UI for the addon that is visible in Blender."""
+
+    bl_idname = "SCENE_PT_SegmentPanel"
     bl_space_type = "VIEW_3D"
     bl_region_type = "UI"
     bl_label = "Segment"
     bl_category = "ZPY"
-    bl_options = {'DEFAULT_CLOSED'}
+    bl_options = {"DEFAULT_CLOSED"}
 
     def draw(self, context):
         layout = self.layout
@@ -317,14 +315,14 @@ class SCENE_PT_SegmentPanel(bpy.types.Panel):
         row.label(text="Segment Selected Objects")
         row = layout.row()
         row.operator(
-            'object.zpy_segment_instance_single',
-            text='Single',
-            icon='USER',
+            "object.zpy_segment_instance_single",
+            text="Single",
+            icon="USER",
         )
         row.operator(
-            'object.zpy_segment_instance_many',
-            text='Many',
-            icon='COMMUNITY',
+            "object.zpy_segment_instance_many",
+            text="Many",
+            icon="COMMUNITY",
         )
         row = layout.row()
         row.prop(context.scene, "categories_enum", text="")
@@ -332,38 +330,38 @@ class SCENE_PT_SegmentPanel(bpy.types.Panel):
         row.label(text="Visualize")
         row = layout.row()
         row.operator(
-            'object.zpy_visualize_instance',
-            text='Visualize Instances',
-            icon='HIDE_OFF',
+            "object.zpy_visualize_instance",
+            text="Visualize Instances",
+            icon="HIDE_OFF",
         )
         row = layout.row()
         row.operator(
-            'object.zpy_visualize_category',
-            text='Visualize Categories',
-            icon='HIDE_OFF',
+            "object.zpy_visualize_category",
+            text="Visualize Categories",
+            icon="HIDE_OFF",
         )
 
         row = layout.row()
         row.label(text="Load Categories")
         row = layout.row()
         row.operator(
-            'object.zpy_categories_from_text',
-            text='Text',
-            icon='TEXT',
+            "object.zpy_categories_from_text",
+            text="Text",
+            icon="TEXT",
         )
         row.operator(
-            'object.zpy_categories_from_zumo',
-            text='Json',
-            icon='FILEBROWSER',
+            "object.zpy_categories_from_zumo",
+            text="Json",
+            icon="FILEBROWSER",
         )
 
         row = layout.row()
         row.label(text="Selected Object Data")
         row = layout.row()
         row.operator(
-            'object.zpy_reset_seg_data',
-            text='Reset Seg Data',
-            icon='FILE_REFRESH',
+            "object.zpy_reset_seg_data",
+            text="Reset Seg Data",
+            icon="FILE_REFRESH",
         )
         row = layout.row()
         row.label(text="Instance")
